/**
 * Implementation of the Hamming Distance on Strings.
 * 
 * @author Nils.Hoffmann@CeBiTec.Uni-Bielefeld.DE
 */
public class HammingDistance {

    /**
     * Computes the Hamming Distance between two Strings.
     * Both need to have the same length, otherwise an Exception
     * of type java.lang.IllegalArgumentException is raised.
     *
     * Strings are used as-is, no lower- or uppercasing is performed!
     *
     * @param a
     * @param b
     * @throws IllegalArgumentException
     * @return
     */
    public double getDistance(String a, String b) throws IllegalArgumentException{
        //String Laengen ueberpruefen
        if(a.length()!=b.length()) {
            //Exception ausloesen, wenn ungleich
            throw new IllegalArgumentException("String lengths are not equal: "+a.length()+"!="+b.length());
        }
        //groesster gemeinsamer index -> da beide gleich sind, eigentlich
        //ueberfluessig
        int maxindex = Math.min(a.length(),b.length());
        //distanz
        int d = 0;
        //Schleife ueber die Strings
        for(int i=0;i<maxindex;i++) {
            //addiere 0 wenn a(i)==b(i), 1 sonst
            d += (a.charAt(i)==b.charAt(i)?0:1);
        }
        //gib die Distanz zurueck
        return d;
    }

    public static void main(String[] args) {
        HammingDistance hd = new HammingDistance();
        String a = "Der Hunne Attila";
        String b = "Die Henne Ottili";
        double d = hd.getDistance(a, b);
        System.out.println("Distance of "+a+" and "+b+" = "+((int)d));
        String c = "Die Stadt Manila";
        d = hd.getDistance(a, c);
        System.out.println("Distance of "+a+" and "+c+" = "+((int)d));
        System.out.println("Da wir die Exception abgefangen haben, koennen wir unser Programm hier fortsetzen!");
    }

}
